@@ -11,11 +11,14 @@ class BaseModeratedObjectForm(ModelForm):
 
         if instance:
             try:
-                if instance.moderated_object.moderation_status in \
-                [MODERATION_STATUS_PENDING, MODERATION_STATUS_REJECTED]:
-                    initial = \
+                if instance.moderated_object.moderation_status in\
+                   [MODERATION_STATUS_PENDING, MODERATION_STATUS_REJECTED] and\
+                   not instance.moderated_object.moderator.\
+                   visible_until_rejected:
+                    initial =\
                     instance.moderated_object.changed_object.__dict__
-                    kwargs['initial'] = initial
+                    kwargs.setdefault('initial', {})
+                    kwargs['initial'].update(initial)
             except ObjectDoesNotExist:
                 pass
 
