@@ -9,12 +9,14 @@ INSTALLED_APPS = (
     'django.contrib.admin',
     'django.contrib.sites',
     'moderation',
-    'moderation.tests.test_app',
-)
+    'moderation.tests.apps.test_app1',
+    )
 
-ROOT_URLCONF = 'moderation.tests.test_urls.py'
+SERIALIZATION_MODULES = {}
+
+ROOT_URLCONF = 'moderation.tests.urls.default.py'
 
 DJANGO_MODERATION_MODERATORS = (
-                               'test@example.com',
-                               )
+    'test@example.com',
+    )
 settings = get_only_settings_locals(locals().copy())
